@@ -6,6 +6,9 @@ use rlib '../../../../..';
 package Devel::Trepan::CmdProcessor::Command::Load::Command;
 use Cwd 'abs_path';
 
+# FIXME: allow specifying just the Perl module name,
+# e.g. File::Basename a command name, e.g. alias.
+
 use Devel::Trepan::CmdProcessor::Command::Subcmd::Core;
 
 use strict;
@@ -13,9 +16,6 @@ our (@ISA, @SUBCMD_VARS);
 # Values inherited from parent
 use vars @Devel::Trepan::CmdProcessor::Command::Subcmd::SUBCMD_VARS;
 
-## FIXME: do automatically.
-our $CMD = "load command";
-
 unless (@ISA) {
     eval <<"EOE";
     use constant MAX_ARGS => undef;  # unlimited.
