@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2011-2013 Rocky Bernstein <rocky@cpan.org>
+# Copyright (C) 2011-2014 Rocky Bernstein <rocky@cpan.org>
 use warnings; no warnings 'redefine'; no warnings 'once';
 
 package Devel::Trepan::CmdProcessor::Command::Set::Max::String;
@@ -19,15 +19,25 @@ use vars qw(@ISA @SUBCMD_VARS);
 use vars @Devel::Trepan::CmdProcessor::Command::Subsubcmd::SUBCMD_VARS;
 
 our $IN_LIST      = 1;
+=pod
+
+=head2 Synopsis:
+
+=cut
+
 our $HELP         = <<'HELP';
 =pod
 
-B<Set max st>[B<ring>] I<number>
+B<Set max string>] I<count>
 
 Sometimes the string representation of an object is very long. This
 setting limits how much of the string representation you want to
 see. However if the string has an embedded newline then we will assume
 the output is intended to be formated as is.
+
+=head2 See also:
+
+L<C<show max string>|Devel::Trepan::CmdProcessor::Command::Show::Max::String>
 =cut
 HELP
 
