@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2011 Rocky Bernstein <rocky@cpan.org>
+# Copyright (C) 2011, 2014 Rocky Bernstein <rocky@cpan.org>
 use warnings; no warnings 'redefine'; no warnings 'once';
 use rlib '../../../../../..';
 
@@ -15,9 +15,27 @@ use vars @Devel::Trepan::CmdProcessor::Command::Subsubcmd::SUBCMD_VARS;
 
 our $IN_LIST      = 1;
 our $MIN_ABBREV   = length('p');
+=pod
+
+=head2 Synopsis:
+
+=cut
+our $HELP         = <<"HELP";
+=pod
+
+B<show trace print>
+
+Show tracing print (set -x) status.
+
+=head2 See also:
+
+L<C<set trace print>|Devel::Trepan::CmdProcessor::Set::Trace::Print>
+
+=cut
+HELP
+
 our $SHORT_HELP   = "Show tracing print (set -x) status";
-our $HELP         = $SHORT_HELP;
- 
+
 unless (caller) {
   # Demo it.
   # require_relative '../../../mock'
